/**
 * Forwarding system module
 * Provides a flexible and type-safe way to configure and manage various forwarding strategies
 */

// Export handlers
export { ForwardingHandler } from './handlers/base-handler.js';
export * from './handlers/http-handler.js';
export * from './handlers/https-passthrough-handler.js';
export * from './handlers/https-terminate-to-http-handler.js';
export * from './handlers/https-terminate-to-https-handler.js';

// Export factory
export * from './factory/forwarding-factory.js';

// Export types - these include TForwardingType and IForwardConfig
export type { 
  TForwardingType,
  IForwardConfig,
  IForwardingHandler
} from './config/forwarding-types.js';

export { 
  ForwardingHandlerEvents
} from './config/forwarding-types.js';

// Export route helpers directly from route-patterns
export {
  createHttpRoute,
  createHttpsTerminateRoute,
  createHttpsPassthroughRoute,
  createHttpToHttpsRedirect,
  createCompleteHttpsServer,
  createLoadBalancerRoute
} from '../proxies/smart-proxy/utils/route-patterns.js';